summaryrefslogtreecommitdiffstats
path: root/kmail/kmfolderseldlg.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfolderseldlg.h')
-rw-r--r--kmail/kmfolderseldlg.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmail/kmfolderseldlg.h b/kmail/kmfolderseldlg.h
index 81bdd7eb..edc5f6a7 100644
--- a/kmail/kmfolderseldlg.h
+++ b/kmail/kmfolderseldlg.h
@@ -26,13 +26,13 @@ namespace KMail {
public:
/**
* Constructor with KMMainWidget
* @p tqparent @em must be a KMMainWin, because we
* need its foldertree.
* @param mustBeReadWrite if true, readonly folders are disabled
* @param useGlobalSettings if true, the current folder is read and
* written to GlobalSettings
*/
- KMFolderSelDlg( KMMainWidget * tqparent, const TQString& caption,
+ KMFolderSelDlg( KMMainWidget * parent, const TQString& caption,
bool mustBeReadWrite, bool useGlobalSettings = true );
/**
* Constructor with separate KMFolderTree
@@ -40,7 +40,7 @@ namespace KMail {
* @param useGlobalSettings if true, the current folder is read and
* written to GlobalSettings
*/
- KMFolderSelDlg( TQWidget * tqparent, KMFolderTree * tree,
+ KMFolderSelDlg( TQWidget * parent, KMFolderTree * tree,
const TQString& caption, bool mustBeReadWrite,
bool useGlobalSettings = true );
@@ -26,13 +26,13 @@ namespace KMail {
/**
* Constructor with KMMainWidget
- * @p tqparent @em must be a KMMainWin, because we
+ * @p parent @em must be a KMMainWin, because we
* need its foldertree.
* @param mustBeReadWrite if true, readonly folders are disabled